DartWebPluginBaseMethodChannel<M, A, R> class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<int>
inherited
invokeMethodJs(MethodCall call) → Future<DartWebPluginBaseChannelMessageArguments<M, R>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMessageFromDart(DartWebPluginBaseChannelMessageArguments<M, A> arguments) → Future<DartWebPluginBaseChannelMessageArguments<M, R>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited