DartWebPluginBasePlugin<M, A, R> class

A web implementation of the DartWebPluginBasePlatform of the DartWebPluginBase plugin.

Inheritance

Constructors

DartWebPluginBasePlugin(void onMessageFromJs(DartWebPluginBaseChannelMessageArguments<M, R>)?)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onMessageFromJs → void Function(DartWebPluginBaseChannelMessageArguments<M, R>)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<int>
inherited
invokeMethodJs(MethodCall call) → Future<DartWebPluginBaseChannelMessageArguments<M, R>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void